==> haskell-cassava-megaparsec-2.1.1-123-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cassava-megaparsec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 cassava-megaparsec
version:              2.1.1
visibility:           public
id:                   cassava-megaparsec-2.1.1-E7QCu2NKJ64ImLqWm5vsKU
key:                  cassava-megaparsec-2.1.1-E7QCu2NKJ64ImLqWm5vsKU
license:              MIT
maintainer:           Mark Karpov <markkarpov92@gmail.org>
author:               Mark Karpov <markkarpov92@gmail.org>
homepage:             https://github.com/stackbuilders/cassava-megaparsec
synopsis:
    Megaparsec parser of CSV files that plays nicely with Cassava

description:
    Megaparsec parser of CSV files that plays nicely with Cassava.

category:             Text, Web, CSV, Parsing
abi:                  191e4f77146fd56a9ebe649c2a190fa9
exposed:              True
exposed-modules:
    Data.Csv.Parser.Megaparsec Data.Csv.Parser.Megaparsec.Internals

import-dirs:          /usr/lib/ghc-9.4.8/site-local/cassava-megaparsec-2.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/cassava-megaparsec-2.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/cassava-megaparsec-2.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cassava-megaparsec
hs-libraries:         HScassava-megaparsec-2.1.1-E7QCu2NKJ64ImLqWm5vsKU
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    cassava-0.5.4.1-Fa5MhephXv32XsZlJqWK0h
    megaparsec-9.7.0-7jzSygYb9UCHSxVBa30IvK
    unordered-containers-0.2.20-I3GOf8berWn8tol6ImoSEe
    vector-0.13.2.0-7bZcynEBhMGLMgNICkU4Wg

haddock-interfaces:
    /usr/share/doc/haskell-cassava-megaparsec/html/cassava-megaparsec.haddock

haddock-html:         /usr/share/doc/haskell-cassava-megaparsec/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cassava-megaparsec-2.1.1-124-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cassava-megaparsec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 cassava-megaparsec
version:              2.1.1
visibility:           public
id:                   cassava-megaparsec-2.1.1-2Ldk9tOc5xO5IwRiAmHAhI
key:                  cassava-megaparsec-2.1.1-2Ldk9tOc5xO5IwRiAmHAhI
license:              MIT
maintainer:           Mark Karpov <markkarpov92@gmail.org>
author:               Mark Karpov <markkarpov92@gmail.org>
homepage:             https://github.com/stackbuilders/cassava-megaparsec
synopsis:
    Megaparsec parser of CSV files that plays nicely with Cassava

description:
    Megaparsec parser of CSV files that plays nicely with Cassava.

category:             Text, Web, CSV, Parsing
abi:                  13736077f3101407f4a7b70ce73cf846
exposed:              True
exposed-modules:
    Data.Csv.Parser.Megaparsec Data.Csv.Parser.Megaparsec.Internals

import-dirs:          /usr/lib/ghc-9.4.8/site-local/cassava-megaparsec-2.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/cassava-megaparsec-2.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/cassava-megaparsec-2.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cassava-megaparsec
hs-libraries:         HScassava-megaparsec-2.1.1-2Ldk9tOc5xO5IwRiAmHAhI
depends:
    base-4.17.2.1 bytestring-0.11.5.3
    cassava-0.5.4.1-6q0OLorsNaxKS3RilElHfN
    megaparsec-9.7.0-EujlCtvd6hmm53pqN4SFa
    unordered-containers-0.2.20-79maJZZuZDu8bRI1CHuoJG
    vector-0.13.2.0-9TreTxHfwqF7cSCfMWPj9u

haddock-interfaces:
    /usr/share/doc/haskell-cassava-megaparsec/html/cassava-megaparsec.haddock

haddock-html:         /usr/share/doc/haskell-cassava-megaparsec/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
